@@ -7,6 +7,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
+	fos "github.com/aquasecurity/fanal/analyzer/os"
 	ftypes "github.com/aquasecurity/fanal/types"
 	"github.com/aquasecurity/trivy-db/pkg/db"
 	dbTypes "github.com/aquasecurity/trivy-db/pkg/types"
@@ -30,12 +31,12 @@ func TestClient_FillVulnerabilityInfo(t *testing.T) {
 	}{
 		{
 			name:     "happy path, with only OS vulnerability but no vendor severity, no NVD",
-			fixtures: []string{"testdata/fixtures/full.yaml"},
+			fixtures: []string{"testdata/fixtures/vulnerability.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
 					{VulnerabilityID: "CVE-2019-0001"},
 				},
-				reportType: vulnerability.RedHat,
+				reportType: fos.RedHat,
 			},
 			expectedVulnerabilities: []types.DetectedVulnerability{
 				{
@@ -54,12 +55,19 @@ func TestClient_FillVulnerabilityInfo(t *testing.T) {
 		},
 		{
 			name:     "happy path, with only OS vulnerability but no vendor severity, yes NVD",
-			fixtures: []string{"testdata/fixtures/full.yaml"},
+			fixtures: []string{"testdata/fixtures/vulnerability.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
-					{VulnerabilityID: "CVE-2019-0002"},
+					{
+						VulnerabilityID: "CVE-2019-0002",
+						DataSource: &dbTypes.DataSource{
+							ID:   vulnerability.Ubuntu,
+							Name: "Ubuntu CVE Tracker",
+							URL:  "https://git.launchpad.net/ubuntu-cve-tracker",
+						},
+					},
 				},
-				reportType: vulnerability.Ubuntu,
+				reportType: fos.Ubuntu,
 			},
 			expectedVulnerabilities: []types.DetectedVulnerability{
 				{
@@ -74,17 +82,29 @@ func TestClient_FillVulnerabilityInfo(t *testing.T) {
 					},
 					SeveritySource: vulnerability.NVD,
 					PrimaryURL:     "https://avd.aquasec.com/nvd/cve-2019-0002",
+					DataSource: &dbTypes.DataSource{
+						ID:   vulnerability.Ubuntu,
+						Name: "Ubuntu CVE Tracker",
+						URL:  "https://git.launchpad.net/ubuntu-cve-tracker",
+					},
 				},
 			},
 		},
 		{
 			name:     "happy path, with only OS vulnerability but no severity, no vendor severity, no NVD",
-			fixtures: []string{"testdata/fixtures/full.yaml"},
+			fixtures: []string{"testdata/fixtures/vulnerability.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
-					{VulnerabilityID: "CVE-2019-0003"},
+					{
+						VulnerabilityID: "CVE-2019-0003",
+						DataSource: &dbTypes.DataSource{
+							ID:   vulnerability.Ubuntu,
+							Name: "Ubuntu CVE Tracker",
+							URL:  "https://git.launchpad.net/ubuntu-cve-tracker",
+						},
+					},
 				},
-				reportType: vulnerability.Ubuntu,
+				reportType: fos.Ubuntu,
 			},
 			expectedVulnerabilities: []types.DetectedVulnerability{
 				{
@@ -96,17 +116,29 @@ func TestClient_FillVulnerabilityInfo(t *testing.T) {
 						References:  []string{"http://example.com"},
 					},
 					PrimaryURL: "https://avd.aquasec.com/nvd/cve-2019-0003",
+					DataSource: &dbTypes.DataSource{
+						ID:   vulnerability.Ubuntu,
+						Name: "Ubuntu CVE Tracker",
+						URL:  "https://git.launchpad.net/ubuntu-cve-tracker",
+					},
 				},
 			},
 		},
 		{
 			name:     "happy path, with only OS vulnerability, yes vendor severity, with both NVD and CVSS info",
-			fixtures: []string{"testdata/fixtures/full.yaml"},
+			fixtures: []string{"testdata/fixtures/vulnerability.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
-					{VulnerabilityID: "CVE-2019-0004"},
+					{
+						VulnerabilityID: "CVE-2019-0004",
+						DataSource: &dbTypes.DataSource{
+							ID:   vulnerability.RedHat,
+							Name: "Red Hat OVAL v2",
+							URL:  "https://www.redhat.com/security/data/oval/v2/",
+						},
+					},
 				},
-				reportType: vulnerability.CentOS,
+				reportType: fos.CentOS,
 			},
 			expectedVulnerabilities: []types.DetectedVulnerability{
 				{
@@ -117,7 +149,7 @@ func TestClient_FillVulnerabilityInfo(t *testing.T) {
 						Severity:    dbTypes.SeverityLow.String(),
 						CweIDs:      []string{"CWE-311"},
 						References:  []string{"http://example.com"},
-						CVSS: map[string]dbTypes.CVSS{
+						CVSS: map[dbTypes.SourceID]dbTypes.CVSS{
 							vulnerability.NVD: {
 								V2Vector: "AV:N/AC:L/Au:N/C:P/I:P/A:P",
 								V2Score:  4.5,
@@ -134,56 +166,27 @@ func TestClient_FillVulnerabilityInfo(t *testing.T) {
 					},
 					SeveritySource: vulnerability.RedHat,
 					PrimaryURL:     "https://avd.aquasec.com/nvd/cve-2019-0004",
-				},
-			},
-		},
-		{
-			name:     "happy path light db, with only OS vulnerability, yes vendor severity",
-			fixtures: []string{"testdata/fixtures/light.yaml"},
-			args: args{
-				vulns: []types.DetectedVulnerability{
-					{VulnerabilityID: "CVE-2020-0001"},
-				},
-				reportType: vulnerability.Ubuntu,
-			},
-			expectedVulnerabilities: []types.DetectedVulnerability{
-				{
-					VulnerabilityID: "CVE-2020-0001",
-					Vulnerability: dbTypes.Vulnerability{
-						Title:    "dos",
-						Severity: dbTypes.SeverityLow.String(),
+					DataSource: &dbTypes.DataSource{
+						ID:   vulnerability.RedHat,
+						Name: "Red Hat OVAL v2",
+						URL:  "https://www.redhat.com/security/data/oval/v2/",
 					},
-					SeveritySource: vulnerability.Ubuntu,
-					PrimaryURL:     "https://avd.aquasec.com/nvd/cve-2020-0001",
-				},
-			},
-		},
-		{
-			name:     "happy path light db, with only OS vulnerability, no vendor severity",
-			fixtures: []string{"testdata/fixtures/light.yaml"},
-			args: args{
-				vulns: []types.DetectedVulnerability{
-					{VulnerabilityID: "CVE-2020-0002"},
-				},
-				reportType: vulnerability.Alpine,
-			},
-			expectedVulnerabilities: []types.DetectedVulnerability{
-				{
-					VulnerabilityID: "CVE-2020-0002",
-					Vulnerability: dbTypes.Vulnerability{
-						Title:    "dos",
-						Severity: dbTypes.SeverityUnknown.String(),
-					},
-					PrimaryURL: "https://avd.aquasec.com/nvd/cve-2020-0002",
 				},
 			},
 		},
 		{
 			name:     "happy path, with only library vulnerability",
-			fixtures: []string{"testdata/fixtures/full.yaml"},
+			fixtures: []string{"testdata/fixtures/vulnerability.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
-					{VulnerabilityID: "CVE-2019-0005"},
+					{
+						VulnerabilityID: "CVE-2019-0005",
+						DataSource: &dbTypes.DataSource{
+							ID:   vulnerability.GHSA,
+							Name: "GitHub Security Advisory Pip",
+							URL:  "https://github.com/advisories?query=type%3Areviewed+ecosystem%3Apip",
+						},
+					},
 				},
 				reportType: ftypes.Poetry,
 			},
@@ -196,14 +199,19 @@ func TestClient_FillVulnerabilityInfo(t *testing.T) {
 						Severity:    dbTypes.SeverityCritical.String(),
 						References:  []string{"https://www.who.int/emergencies/diseases/novel-coronavirus-2019"},
 					},
-					SeveritySource: vulnerability.PythonSafetyDB,
+					SeveritySource: vulnerability.GHSA,
 					PrimaryURL:     "https://avd.aquasec.com/nvd/cve-2019-0005",
+					DataSource: &dbTypes.DataSource{
+						ID:   vulnerability.GHSA,
+						Name: "GitHub Security Advisory Pip",
+						URL:  "https://github.com/advisories?query=type%3Areviewed+ecosystem%3Apip",
+					},
 				},
 			},
 		},
 		{
 			name:     "happy path, with package-specific severity",
-			fixtures: []string{"testdata/fixtures/full.yaml"},
+			fixtures: []string{"testdata/fixtures/vulnerability.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
 					{
@@ -214,7 +222,7 @@ func TestClient_FillVulnerabilityInfo(t *testing.T) {
 						},
 					},
 				},
-				reportType: vulnerability.Debian,
+				reportType: fos.Debian,
 			},
 			expectedVulnerabilities: []types.DetectedVulnerability{
 				{
@@ -263,9 +271,9 @@ func TestClient_FillVulnerabilityInfo(t *testing.T) {
 
 func TestClient_getPrimaryURL(t *testing.T) {
 	type args struct {
-		vulnID  string
-		refs    []string
-		sources []string
+		vulnID string
+		refs   []string
+		source dbTypes.SourceID
 	}
 	tests := []struct {
 		name string
@@ -275,36 +283,36 @@ func TestClient_getPrimaryURL(t *testing.T) {
 		{
 			name: "CVE-ID",
 			args: args{
-				vulnID:  "CVE-2014-8484",
-				refs:    []string{"http://linux.oracle.com/cve/CVE-2014-8484.html"},
-				sources: []string{vulnerability.OracleOVAL},
+				vulnID: "CVE-2014-8484",
+				refs:   []string{"http://linux.oracle.com/cve/CVE-2014-8484.html"},
+				source: vulnerability.OracleOVAL,
 			},
 			want: "https://avd.aquasec.com/nvd/cve-2014-8484",
 		},
 		{
 			name: "RUSTSEC",
 			args: args{
-				vulnID:  "RUSTSEC-2018-0017",
-				refs:    []string{"https://github.com/rust-lang-deprecated/tempdir/pull/46"},
-				sources: []string{vulnerability.RustSec},
+				vulnID: "RUSTSEC-2018-0017",
+				refs:   []string{"https://github.com/rust-lang-deprecated/tempdir/pull/46"},
+				source: vulnerability.OSV,
 			},
-			want: "https://rustsec.org/advisories/RUSTSEC-2018-0017",
+			want: "https://osv.dev/vulnerability/RUSTSEC-2018-0017",
 		},
 		{
 			name: "GHSA",
 			args: args{
-				vulnID:  "GHSA-28fw-88hq-6jmm",
-				refs:    []string{},
-				sources: []string{vulnerability.PhpSecurityAdvisories},
+				vulnID: "GHSA-28fw-88hq-6jmm",
+				refs:   []string{},
+				source: vulnerability.PhpSecurityAdvisories,
 			},
 			want: "https://github.com/advisories/GHSA-28fw-88hq-6jmm",
 		},
 		{
 			name: "Debian temp vulnerability",
 			args: args{
-				vulnID:  "TEMP-0841856-B18BAF",
-				refs:    []string{},
-				sources: []string{vulnerability.DebianOVAL},
+				vulnID: "TEMP-0841856-B18BAF",
+				refs:   []string{},
+				source: vulnerability.Debian,
 			},
 			want: "https://security-tracker.debian.org/tracker/TEMP-0841856-B18BAF",
 		},
@@ -317,7 +325,7 @@ func TestClient_getPrimaryURL(t *testing.T) {
 					"https://github.com/lodash/lodash/pull/4759",
 					"https://www.npmjs.com/advisories/1523",
 				},
-				sources: []string{vulnerability.NodejsSecurityWg},
+				source: vulnerability.NodejsSecurityWg,
 			},
 			want: "https://www.npmjs.com/advisories/1523",
 		},
@@ -329,7 +337,7 @@ func TestClient_getPrimaryURL(t *testing.T) {
 					"http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00076.html",
 					"https://www.suse.com/support/security/rating/",
 				},
-				sources: []string{vulnerability.OpenSuseCVRF},
+				source: vulnerability.SuseCVRF,
 			},
 			want: "http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00076.html",
 		},
@@ -337,7 +345,7 @@ func TestClient_getPrimaryURL(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			c := Client{}
-			got := c.getPrimaryURL(tt.args.vulnID, tt.args.refs, tt.args.sources)
+			got := c.getPrimaryURL(tt.args.vulnID, tt.args.refs, tt.args.source)
 			assert.Equal(t, tt.want, got)
 		})
 	}
