@@ -28,7 +28,6 @@ var StandaloneSuperSet = wire.NewSet(
 
 // StandaloneDockerSet binds docker dependencies
 var StandaloneDockerSet = wire.NewSet(
-	types.GetDockerOption,
 	image.NewDockerImage,
 	aimage.NewArtifact,
 	StandaloneSuperSet,
@@ -63,7 +62,6 @@ var RemoteSuperSet = wire.NewSet(
 
 // RemoteDockerSet binds remote docker dependencies
 var RemoteDockerSet = wire.NewSet(
-	types.GetDockerOption,
 	image.NewDockerImage,
 	RemoteSuperSet,
 )
@@ -82,8 +80,8 @@ type Scanner struct {
 
 // Driver defines operations of scanner
 type Driver interface {
-	Scan(target string, imageID string, layerIDs []string, options types.ScanOptions) (
-		results report.Results, osFound *ftypes.OS, eols bool, err error)
+	Scan(target string, artifactKey string, blobKeys []string, options types.ScanOptions) (
+		results report.Results, osFound *ftypes.OS, err error)
 }
 
 // NewScanner is the factory method of Scanner
@@ -98,24 +96,49 @@ func (s Scanner) ScanArtifact(ctx context.Context, options types.ScanOptions) (r
 		return report.Report{}, xerrors.Errorf("failed analysis: %w", err)
 	}
 
-	results, osFound, eosl, err := s.driver.Scan(artifactInfo.Name, artifactInfo.ID, artifactInfo.BlobIDs, options)
+	results, osFound, err := s.driver.Scan(artifactInfo.Name, artifactInfo.ID, artifactInfo.BlobIDs, options)
 	if err != nil {
 		return report.Report{}, xerrors.Errorf("scan failed: %w", err)
 	}
-	if eosl {
+
+	if osFound != nil && osFound.Eosl {
 		log.Logger.Warnf("This OS version is no longer supported by the distribution: %s %s", osFound.Family, osFound.Name)
 		log.Logger.Warnf("The vulnerability detection may be insufficient because security updates are not provided")
 	}
 
+	// Layer makes sense only when scanning container images
+	if artifactInfo.Type != ftypes.ArtifactContainerImage {
+		removeLayer(results)
+	}
+
 	return report.Report{
 		SchemaVersion: report.SchemaVersion,
 		ArtifactName:  artifactInfo.Name,
 		ArtifactType:  artifactInfo.Type,
 		Metadata: report.Metadata{
 			OS:          osFound,
-			RepoTags:    artifactInfo.RepoTags,
-			RepoDigests: artifactInfo.RepoDigests,
+			ImageID:     artifactInfo.ImageMetadata.ID,
+			DiffIDs:     artifactInfo.ImageMetadata.DiffIDs,
+			RepoTags:    artifactInfo.ImageMetadata.RepoTags,
+			RepoDigests: artifactInfo.ImageMetadata.RepoDigests,
+			ImageConfig: artifactInfo.ImageMetadata.ConfigFile,
 		},
 		Results: results,
 	}, nil
 }
+
+func removeLayer(results report.Results) {
+	for i := range results {
+		result := results[i]
+
+		for j := range result.Packages {
+			result.Packages[j].Layer = ftypes.Layer{}
+		}
+		for j := range result.Vulnerabilities {
+			result.Vulnerabilities[j].Layer = ftypes.Layer{}
+		}
+		for j := range result.Misconfigurations {
+			result.Misconfigurations[j].Layer = ftypes.Layer{}
+		}
+	}
+}
